@@ -3,28 +3,29 @@
 #' A locale object tries to capture all the defaults that can vary between
 #' countries. You set the locale in once, and the details are automatically
 #' passed on down to the columns parsers. The defaults have been chosen to
-#' match R (i.e. US English) as closely as possible.
+#' match R (i.e. US English) as closely as possible. See
+#' `vignette("locales")` for more details.
 #'
 #' @param date_names Character representations of day and month names. Either
-#'   the language code as string (passed on to \code{\link{date_names_lang}})
-#'   or an object created by \code{\link{date_names}}.
+#'   the language code as string (passed on to [date_names_lang()])
+#'   or an object created by [date_names()].
 #' @param date_format,time_format Default date and time formats.
 #' @param decimal_mark,grouping_mark Symbols used to indicate the decimal
-#'   place, and to chunk larger numbers. Decimal mark can only be \code{,} or
-#'   \code{.}.
+#'   place, and to chunk larger numbers. Decimal mark can only be `,` or
+#'   `.`.
 #' @param tz Default tz. This is used both for input (if the time zone isn't
 #'   present in individual strings), and for output (to control the default
 #'   display). The default is to use "UTC", a time zone that does not use
 #'   daylight savings time (DST) and hence is typically most useful for data.
-#'   The absense of time zones makes it approximately 50x faster to generate
+#'   The absence of time zones makes it approximately 50x faster to generate
 #'   UTC times than any other time zone.
 #'
-#'   Use \code{""} to use the system default time zone, but beware that this
+#'   Use `""` to use the system default time zone, but beware that this
 #'   will not be reproducible across systems.
 #'
-#'   For a complete list of possible time zones, see \code{\link{OlsonNames}()}.
+#'   For a complete list of possible time zones, see [OlsonNames()].
 #'   Americans, note that "EST" is a Canadian time zone that does not have
-#'   DST. It is \emph{not} Eastern Standard Time. It's better to use
+#'   DST. It is *not* Eastern Standard Time. It's better to use
 #'   "US/Eastern", "US/Central" etc.
 #' @param encoding Default encoding. This only affects how the file is
 #'   read - readr always converts the output to UTF-8.
@@ -63,7 +64,7 @@ locale <- function(date_names = "en",
     stop("`decimal_mark` and `grouping_mark` must be different", call. = FALSE)
   }
 
-  check_tz(tz)
+  tz <- check_tz(tz)
   check_encoding(encoding)
 
   structure(
@@ -85,8 +86,10 @@ is.locale <- function(x) inherits(x, "locale")
 #' @export
 print.locale <- function(x, ...) {
   cat("<locale>\n")
-  cat("Numbers:  ", prettyNum(123456.78, big.mark = x$grouping_mark,
-    decimal.mark = x$decimal_mark, digits = 8), "\n", sep = "")
+  cat("Numbers:  ", prettyNum(123456.78,
+    big.mark = x$grouping_mark,
+    decimal.mark = x$decimal_mark, digits = 8
+  ), "\n", sep = "")
   cat("Formats:  ", x$date_format, " / ", x$time_format, "\n", sep = "")
   cat("Timezone: ", x$tz, "\n", sep = "")
   cat("Encoding: ", x$encoding, "\n", sep = "")
@@ -108,19 +111,27 @@ default_locale <- function() {
 check_tz <- function(x) {
   stopifnot(is.character(x), length(x) == 1)
 
-  if (identical(x, ""))
-    return(TRUE)
+  if (identical(x, "")) {
+    x <- Sys.timezone()
 
-  if (x %in% OlsonNames())
-    return(TRUE)
+    if (identical(x, "") || identical(x, NA_character_)) {
+      x <- "UTC"
+    }
+  }
 
-  stop("Unknown TZ ", x, call. = FALSE)
+  if (x %in% tzdb::tzdb_names()) {
+    x
+  } else {
+    stop("Unknown TZ ", x, call. = FALSE)
+  }
 }
+
 check_encoding <- function(x) {
   stopifnot(is.character(x), length(x) == 1)
 
-  if (tolower(x) %in% tolower(iconvlist()))
+  if (tolower(x) %in% tolower(iconvlist())) {
     return(TRUE)
+  }
 
   stop("Unknown encoding ", x, call. = FALSE)
 }
