@@ -362,3 +362,10 @@ test_that("read_csv works with single quotes in skipped lines (#945)", {
   expect_equal(nrow(x), 1)
   expect_equal(ncol(x), 5)
 })
+
+test_that("read_tsv correctly uses the quote and na arguments (#1254, #1255)", {
+  x <- read_tsv(I("foo\tbar\n\"one baz\"\ttwo\nthree\t\n"), quote = "", na = character())
+
+  expect_equal(x[[1]], c("\"one baz\"", "three"))
+  expect_equal(x[[2]], c("two", ""))
+})
